
TODO: TODO_26_15_31_78: categorize git repo existence

When loading git data by FS_67_16_61_97 git plugin, there can be several of specified repo:
*   Path exists or not
*   Path exists: git repo or not.
*   Path exists and git repo: matching git repo root or not.

Instead of failing on negative conditions for each of the point, categorize repo.
